function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? Object(arguments[i]) : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import { createStyledComponent } from '@cloudflare/style-container';
import Cell from './Cell';
const RowWrapper = createStyledComponent(({
  index,
  theme,
  rowHighlight,
  striped,
  expandable,
  disabled,
  isSelected,
  isLoading,
  rowStyle
}) => _objectSpread({
  position: 'relative',
  backgroundColor: theme.colors.background
}, index > 0 && {
  borderTop: `1px solid ${theme.colors.gray[7]}`
}, isSelected && {
  backgroundColor: 'blue.9'
}, !isLoading && disabled && {
  backgroundColor: 'gray.9'
}, expandable && {
  cursor: 'pointer'
}, striped && index % 2 !== 0 ? {
  backgroundColor: 'gray.8'
} : {}, rowHighlight ? {
  transition: 'background-color 0.07s ease-out',
  '&:hover': {
    backgroundColor: 'gray.7'
  }
} : {}, rowStyle || {}));
export const DefaultExpandable = createStyledComponent(({
  theme
}) => ({
  position: 'sticky',
  left: 0,
  px: 1,
  '&:before': {
    content: '""',
    position: 'absolute',
    left: 0,
    top: 0,
    height: '100%',
    width: '4px',
    backgroundColor: theme.colors.blue[3],
    zIndex: 1
  }
}));

const Row = ({
  row,
  rowId,
  rowStyle,
  isLoading,
  expandable,
  isRowExpandable,
  isRowSelectable,
  onlyOneExpanding,
  toggleAllRowsExpanded,
  striped,
  rowHighlight,
  rowIndex,
  onRowClick,
  containerWidth,
  disabled,
  testId
}) => {
  const isExpandable = typeof isRowExpandable === 'function' && !!expandable ? isRowExpandable({
    row
  }) : !!expandable;

  const onClickFn = () => {
    onRowClick({
      isExpanding: !row.isExpanded,
      row
    });

    if (onlyOneExpanding && !row.isExpanded) {
      toggleAllRowsExpanded(false);
      row.toggleRowExpanded(true);
    } else {
      row.toggleRowExpanded();
    }
  };

  const ariaProps = isExpandable ? {
    tabIndex: 0,
    'aria-expanded': !!row.isExpanded,
    onClick: onClickFn,
    onKeyDown: event => {
      if (event.key === 'Enter' || event.key === ' ') {
        event.preventDefault();
        onClickFn();
      }
    }
  } : {};
  return /*#__PURE__*/React.createElement(RowWrapper, {
    "data-testid": testId,
    index: rowIndex,
    rowStyle: rowStyle,
    rowHighlight: rowHighlight,
    striped: striped,
    expandable: isExpandable,
    disabled: disabled,
    isSelected: row.isSelected,
    isLoading: isLoading
  }, /*#__PURE__*/React.createElement("div", _extends({}, row.getRowProps(), ariaProps), row.cells.map((cell, index) => {
    var _cell$getCellProps;

    return /*#__PURE__*/React.createElement(Cell, {
      key: (_cell$getCellProps = cell.getCellProps()) === null || _cell$getCellProps === void 0 ? void 0 : _cell$getCellProps.key,
      id: `${rowId}_cell_${index}`,
      isLoading: isLoading // @ts-ignore
      ,
      cell: cell,
      isExpandable: isExpandable,
      isRowSelectable: isRowSelectable
    });
  })), row.isExpanded && !isLoading && ( // @ts-ignore
  expandable === null || expandable === void 0 ? void 0 : expandable({
    row,
    maxWidth: containerWidth
  })));
};

export default Row;